@@ -388,7 +388,7 @@
 
             pageTabsContainer.dispatchEvent(new CustomEvent("tabchange", {
                 detail: {
-                    selectedTabIndex: libraryBrowser.selectedTabIndex(pageTabsContainer)
+                    selectedTabIndex: libraryBrowser.selectedTab(pageTabsContainer)
                 }
             }));
         }
